==> smisk-1.0.1dev.tar.gz: smisk-1.0.1dev/src/__init__.h <==
/*
Copyright (c) 2007-2008 Rasmus Andersson and contributors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
#ifndef SMISK_MODULE_H
#define SMISK_MODULE_H
#include <Python.h>

// fcgi socket fd
extern int smisk_listensock_fileno;
extern PyObject *os_module;

// static objects at module-level
extern PyObject *smisk_Error; // extends PyExc_StandardError
extern PyObject *smisk_IOError; // extends PyExc_IOError
extern PyObject *smisk_InvalidSessionError; // extends PyExc_ValueError

// Other static strings (only used in C API)
extern PyObject *kString_http;
extern PyObject *kString_https;

#endif

==> smisk-1.1.0a.tar.gz: smisk-1.1.0a/src/__init__.h <==
/*
Copyright (c) 2007-2008 Rasmus Andersson and contributors

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
#ifndef SMISK_MODULE_H
#define SMISK_MODULE_H
#include <Python.h>

// fcgi socket fd
int smisk_listensock_fileno;
PyObject *os_module; // private
PyThreadState *smisk_py_thstate; // private

// The smisk.core module
PyObject *smisk_core_module;

// static objects at module-level
PyObject *smisk_Error; // extends PyExc_StandardError
PyObject *smisk_IOError; // extends PyExc_IOError
PyObject *smisk_InvalidSessionError; // extends PyExc_ValueError

// String constants
PyObject *kString_http;
PyObject *kString_https;

// Functions
PyObject *smisk_bind (PyObject *self, PyObject *args);
PyObject *smisk_unbind (PyObject *self);
PyObject *smisk_listening (PyObject *self, PyObject *args);
PyObject *smisk_uid (PyObject *self, PyObject *args);
PyObject *smisk_pack (PyObject *self, PyObject *args);


#endif
